@@ -1,3 +1,5 @@
+from typing import Callable
+
 from rich.console import Console
 
 all_problems = set()
@@ -7,14 +9,14 @@ def raise_problem(message):
     all_problems.add(message)
 
 
-def report_problems(console: Console):
+def report_problems(console: Callable[[], Console]):
 
     global all_problems
     if not all_problems:
         return
-    console.rule("[red]Problems")
+    console().rule("[red]Problems")
     for problem in all_problems:
-        console.print(f"{problem}")
-        console.print()
+        console().print(f"{problem}")
+        console().print()
 
     all_problems = set()
