@@ -34,12 +34,23 @@ def test_config_pyproject():
 default-flags = ["trim"]
             """,
         }
-    ).run_pytest(changed_files=trimmed_files)
+    ).run_pytest(changed_files=trimmed_files, returncode=snapshot(1))
 
 
 def test_config_env():
-    Example(file_to_trim).run_pytest(
-        env={"INLINE_SNAPSHOT_DEFAULT_FLAGS": "trim"}, changed_files=trimmed_files
+    e = Example(file_to_trim)
+
+    e.run_pytest(
+        env={"INLINE_SNAPSHOT_DEFAULT_FLAGS": "trim"},
+        changed_files=trimmed_files,
+        returncode=snapshot(1),
+    )
+
+    e.run_pytest(
+        stdin=b"\n",
+        env={"INLINE_SNAPSHOT_DEFAULT_FLAGS": "trim"},
+        changed_files=trimmed_files,
+        returncode=snapshot(1),
     )
 
 
@@ -53,7 +64,7 @@ def test_shortcuts():
 strim=["trim"]
             """,
         }
-    ).run_pytest(["--strim"], changed_files=trimmed_files)
+    ).run_pytest(["--strim"], changed_files=trimmed_files, returncode=snapshot(1))
 
 
 def test_default_shortcuts():
@@ -77,4 +88,5 @@ def test_a():
 """
             }
         ),
+        returncode=1,
     )
