@@ -823,7 +823,7 @@ def test_thing():
 | +        )                                                                   |
 | +    )                                                                       |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=create
+These changes will be applied, because you used create
 """
     )
 
@@ -944,7 +944,7 @@ def test_Is():
     )
 
 
-def test_create_elipsis():
+def test_create_ellipsis():
     Example(
         """\
 from inline_snapshot import snapshot
