@@ -8,6 +8,9 @@ from inline_snapshot.testing import Example
 
 @pytest.mark.no_rewriting
 def test_pypy():
+
+    no_cpython = sys.implementation.name != "cpython"
+
     report = (
         snapshot("INFO: inline-snapshot was disabled because pypy is not supported")
         if sys.implementation.name == "pypy"
@@ -23,7 +26,7 @@ def test_pypy():
 | -    assert 1+1==snapshot(3)                                                 |
 | +    assert 1+1==snapshot(2)                                                 |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=fix\
+These changes will be applied, because you used fix\
 """
         )
     )
@@ -36,6 +39,6 @@ def test_example():
     assert 1+1==snapshot(3)
 
     """
-    ).run_pytest(["--inline-snapshot=fix"], report=report).run_pytest(
-        ["--inline-snapshot=disable"], report=""
+    ).run_pytest(["--inline-snapshot=fix"], report=report, returncode=1).run_pytest(
+        ["--inline-snapshot=disable"], report="", returncode=1 if no_cpython else 0
     )
